// 购物车相关
import { request } from "@/lib/service"
import { baseUrl } from '@/config'

/**
 * @desc 获取购物车数量
 */
export function cartCount() {
	return request({
		url: 'zsxcx/cartCount.htm',
		method: 'post'
	})
}

/**
 * @desc 加入购物车
 * @param {int | String} goods_id 商品ID
 * @param {int} cart_number 加入商品数量
 * @param {int | String} sku_id 规格ID
 */
export function addCart(params) {
	return request({
		url: 'zsxcx/addcart.htm',
		method: 'post',
		data: params
	})
}

/**
 * @desc 获取购物车列表
 */
export function cartsList() {
	return request({
		url: 'zsxcx/cartlist.htm',
		method: 'post',
		needMask: true
	})
}

/**
 * @desc 编辑购物车商品
 * @param {int | String} 购物车ID
 * @param {int | String} 编辑后的购买数量
 */
export function editCart({cart_id, cart_number}) {
	return request({
		url: 'zsxcx/editcart.htm',
		data: {
			cart_id,
			cart_number
		},
		method: 'post',
		needMask: true
	})
}


/**
 * @desc 删除购物车商品
 * @param {String} cart_ids // 购物车ids  
 */
export function delCart(cart_ids) {
	return request({
		url: 'zsxcx/delcarts.htm',
		data: { cart_ids },
		method: 'post',
		needMask: true
	})
}
