// 用户相关
import { request, upload } from "@/lib/service"
import md5 from 'md5'

/**
 * @desc wx.login 获取openid unionid等信息
 * @param { String } code  
 */
export function wxLogin(code) {
	return request({
		url: 'zsxcx/getInfo.htm',
		data: {
			js_code: code
		}
	})
}

/**
 * @desc 退出登录
 */
export function logout() {
	return request({
		url: 'zsxcx/loginOut.htm',
		method: 'post',
		needMask: true
	})
}

/**
 * @desc 登录
 * @param {Object} params
 * 
 * lgtype 必填 登录方式：1微信登录 2短信验证码登录 3账号密码登录
 * user 用户名（lgtype!=1时必填）
 * pwd 登录密码（lgtype=3时必填）
 * yzm 登录验证码（lgtype=2时必填
 * encryptedData 加密信息（lgtype=1时必填）
 * iv 加密算法的初始向量（lgtype=1时必填）
 * session_key 会话密钥（lgtype=1时必填）
 */
export function login(params) {
	return request({
		url: 'zsxcx/login.htm',
		method: 'post',
		data: params
	})
}

/**
 * @desc 忘记密码
 * @param { string } f_code 输入验证码
 * @param { string } upwd 新密码
 * @param { string } upwd2 新密码二次输入
 */
export function forgetPwd(params) {
	return request({
		url: 'zsxcx/forgetPwd.htm',
		method: 'post',
		data: params
	})
}

/**
 * @desc 发送登录验证码接口
 * @param { String } phone 
 */
export function loginSms(phone) {
	return request({
		url: 'zsxcx/send_lgmessage.htm',
		method: 'post',
		data: {
			phone,
			sign: md5('glsms' + phone)
		}
	})
}
/**
 * @desc 发送忘记密码验证码接口
 */
export function forgetSms(phone) {
	return request({
		url: 'zsxcx/send_fgmessage.htm',
		method: 'post',
		data: {
			phone,
			sign: md5('glsms' + phone)
		}
	})
}

/**
 * @desc 获取用户头像昵称手机号码
 * @return {  }
 */
export function getUserInfo() {
	return request({
		url: 'zsxcx/avatarXcx.htm',
		method: 'post'
	})
}

/**
 * @desc 修改头像
 * @param { String } tempFile 文件地址
 * @return {  }
 */
export function editAvatar(tempFile) {
	return upload({
		url: 'zsxcx/editAvatarXcx.htm',
		tempFile
	})
}

/**
 * @desc 修改昵称
 * @param { String } nickname 
 */
export function editNickname(nickname) {
	return request({
		url: 'zsxcx/editNicknameXcx.htm',
		method: 'post',
		data: {
			nickname
		}
	})
}